capture log close
set more off
set scheme sj

log using taxprep, replace text

use taxprep, clear
xtdes, i(subject) t(time)

* get residuals from multiple regression
quietly regress lntax prep ms hh depend age lntpi mr emp
predict xihat, residuals

* get within-subject correlations of residuals
preserve
keep xihat subject time
reshape wide xihat, i(subject) j(time)
corr xihat*
restore

* plot residuals for first 20 subjects
sort subject time
graph twoway (line xihat time, connect(ascending))      /// 
   if subject<=20, yline(0, lwidth(thick)) xtitle(Time) ///
   ytitle(Resdidual) xscale(range(0.8 5.2))


* estimation of random intercept model using xtreg
xtreg lntax prep ms hh depend age lntpi mr emp, i(subject) mle
* look at variability of mean prep between taxpayers
egen mn_prep = mean(prep), by(subject)
summ mn_prep if time==1
xtsum prep, i(subject)

* estimation of random intercept model using xtmixed
xtmixed lntax prep ms hh depend age lntpi mr emp || subject:, mle

* between-taxpayer effects
xtreg lntax prep ms hh depend age lntpi mr emp, i(subject) be

* within-taxpayer effects
xtreg lntax prep ms hh depend age lntpi mr emp, i(subject) fe

* decompose effect of prep into within and between effects
gen dev_prep = prep - mn_prep
xtreg lntax dev_prep mn_prep ms hh depend age lntpi mr emp, i(subject) mle
lincom dev_prep-mn_prep

* Hausman test
quietly xtreg lntax prep ms hh depend age lntpi mr emp, i(subject) fe
estimates store fixed

quietly xtreg lntax prep ms hh depend age lntpi mr emp, i(subject) re
estimates store random
hausman fixed random

/* Residuals */
gllamm lntax prep ms hh depend age lntpi mr emp, i(subject) adapt
gllapred lev2, ustd
gllapred lev1, pearson

histogram lev1, normal xtitle(Standardized level-1 residuals)

histogram lev2m1 if time==1, normal xtitle(Standardized level-2 residuals)

gllamm, robust

list subject time lntax lev2m1 lev1 if abs(lev1)>4|abs(lev2m1)>4, clean noobs

matrix a=e(b)
gllamm lntax prep ms hh depend age lntpi mr emp if abs(lev1)<4& abs(lev2m1)<4, ///
  i(subject) adapt from(a) robust

log close
exit
