capture log close
log using xc, text replace
set scheme sj
set more off

use fife, clear

* look at structure of data
egen pick_comb = tag(pid sid)
egen numsid = total(pick_comb), by(pid)
sort pid sid
list pid sid numsid if pick_comb & pid<10, clean noobs

egen pick_pid = tag(pid)
tabulate numsid if pick_pid

egen numpid = total(pick_comb), by(sid)
sort sid pid
egen pick_sid = tag(sid)
tabulate numpid if pick_sid

* additive crossed random effects model
xtmixed attain || _all: R.sid || pid:, mle
estimates store model1

* include interaction
xtmixed attain || _all: R.sid || pid: || sid:, mle
estimates store model2

lrtest model1 model2


* diagnostics
estimates restore model1
predict secondary primary, reffects

qnorm secondary if pick_sid, xtitle(Quantiles of normal distribution) ///
  ytitle(Quantiles of empirical Bayes predictions)

qnorm primary if pick_pid, xtitle(Quantiles of normal distribution) ///
  ytitle(Quantiles of empirical Bayes predictions)

* trick

*ssc install supclust, replace

supclust pid sid, gen(region)
egen num=count(attain), by(pid sid)
drop if num<3

drop region
supclust pid sid, gen(region)

sort region sid
by region sid: gen f=_n==1
by region: gen sec=sum(f)
table sec

xtmixed attain || region: R.sec || pid:, mle

log close
exit
